==> salmonjs-0.2.1.tgz: package/test/test.test.js <==
/**
 *               __                         _____ _______
 * .-----.---.-.|  |.--------.-----.-----._|     |     __|
 * |__ --|  _  ||  ||        |  _  |     |       |__     |
 * |_____|___._||__||__|__|__|_____|__|__|_______|_______|
 *
 * salmonJS v0.2.1
 *
 * Copyright (C) 2013 Fabio Cicerchia <info@fabiocicerchia.it>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

var casper   = casper || {},
    fs       = require('fs'),
    rootdir  = fs.absolute('.'),
    srcdir   = rootdir + (casper.cli.has('coverage') ? '/src-cov' : '/src'),
    glob     = require(srcdir + '/glob'),
    basePath = fs.absolute('.') + '/test/assets/';

casper.options.onPageInitialized = function () {
    casper.page.injectJs(srcdir + '/sha1.js');
    casper.page.injectJs(srcdir + '/events.js');
};

casper.on('remote.message', function (msg) {
    console.log('CONSOLE.LOG: ' + msg);
});

casper.test.begin('createNewCaseFile', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj.createNewCaseFile('', 'test', {a: 1}, function () {
        var content;
        try {
            content = fs.read(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'test.tst');
        } catch (ignore) {}

        test.assertEquals(content, undefined, 'doesn\'t create a file if url is empty');
    });

    testObj.createNewCaseFile('http://www.example.com', '', {a: 1}, function () {
        var content;
        try {
            content = fs.read(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/.tst');
        } catch (ignore) {}

        test.assertEquals(content, undefined, 'doesn\'t create a file if name is empty');
    });

    test.done();
});

casper.test.begin('createNewCaseFile #2', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    testObj.createNewCaseFile('http://www.example.com', 'test', {}, function () {
        var content;
        try {
            content = fs.read(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst');
        } catch (ignore) {}

        test.assertEquals(content, undefined, 'doesn\'t create a file if data is empty');
    });

    test.done();
});

casper.test.begin('createNewCaseFile #3', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, rootdir, utils);
    testObj.createNewCaseFile('http://www.example.com', 'test', {POST:{a: 1, b: 2}}, function () {
        var content;
        try {
            content = fs.read(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst');
            fs.remove(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst');
        } catch (ignore) {}

        test.assertMatch(content, /; Test Case File\n; generated by salmonJS v.+ \(.+\) at /);
        test.assertMatch(content, /\n; url = http:\/\/www.example.com\n; id = test\n\n\[POST\]\na=1\nb=2\n/, 'creates a file if url, name and data is not empty');
    });

    test.done();
});

casper.test.begin('getCases', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    testObj.parseCaseFile = function () { return {}; };

    test.assertEquals(testObj.getCases(''), [], 'doesn\'t return anything if there are no matches');
    test.assertEquals(testObj.getCases('non-existent'), [], 'doesn\'t return anything if there are no matches');

    fs.makeDirectory(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com');
    fs.write(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst', '[POST]\na=1\nb=2\n');
    testObj = new Test(fsWrapper, glob, rootdir, utils);
    testObj.parseCaseFile = function () { return {POST:{a: 1, b: 2}}; };

    test.assertEquals(testObj.getCases('http://www.example.com'), [{POST:{a: 1, b: 2}}], 'returns something if there are matches');
    fs.remove(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst');

    test.done();
});

casper.test.begin('parseCaseFile', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    test.assertEquals(testObj.parseCaseFile('non-existent'), {}, 'doesn\'t parse a non existent file');

    test.done();
});

casper.test.begin('parseCaseFile #2', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    test.assertEquals(testObj.parseCaseFile('empty-file'), {}, 'parses an empty file');

    test.done();
});

casper.test.begin('parseCaseFile #3', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    utils.parseINIString = function() { return {a: '1', b: '2'}; };
    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    fs.write(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'not-empty-file.tst', 'a=1\nb=2\n');
    test.assertEquals(testObj.parseCaseFile(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'not-empty-file.tst'), {a: '1', b: '2'}, 'parses a not empty file');
    fs.remove(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'not-empty-file.tst');

    fs.removeTree(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com');

    test.done();
});

==> salmonjs-0.3.0.tgz: package/test/test.test.js <==
/**
 *               __                         _____ _______
 * .-----.---.-.|  |.--------.-----.-----._|     |     __|
 * |__ --|  _  ||  ||        |  _  |     |       |__     |
 * |_____|___._||__||__|__|__|_____|__|__|_______|_______|
 *
 * salmonJS v0.3.0
 *
 * Copyright (C) 2013 Fabio Cicerchia <info@fabiocicerchia.it>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

var casper   = casper || {},
    fs       = require('fs'),
    rootdir  = fs.absolute('.'),
    srcdir   = rootdir + (casper.cli.has('coverage') ? '/src-cov' : '/src'),
    glob     = require(srcdir + '/glob');

casper.options.onPageInitialized = function () {
    casper.page.injectJs(srcdir + '/sha1.js');
    casper.page.injectJs(srcdir + '/events.js');
};

casper.on('remote.message', function (msg) {
    console.log('CONSOLE.LOG: ' + msg);
});

casper.test.begin('createNewCaseFile', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj.createNewCaseFile('', 'test', {a: 1}, function () {
        var content;
        try {
            content = fs.read(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'test.tst');
        } catch (ignore) {}

        test.assertEquals(content, undefined, 'doesn\'t create a file if url is empty');
    });

    testObj.createNewCaseFile('http://www.example.com', '', {a: 1}, function () {
        var content;
        try {
            content = fs.read(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/.tst');
        } catch (ignore) {}

        test.assertEquals(content, undefined, 'doesn\'t create a file if name is empty');
    });

    test.done();
});

casper.test.begin('createNewCaseFile #2', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    testObj.createNewCaseFile('http://www.example.com', 'test', {}, function () {
        var content;
        try {
            content = fs.read(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst');
        } catch (ignore) {}

        test.assertEquals(content, undefined, 'doesn\'t create a file if data is empty');
    });

    test.done();
});

casper.test.begin('createNewCaseFile #3', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, rootdir, utils);
    testObj.createNewCaseFile('http://www.example.com', 'test', {POST:{a: 1, b: 2}}, function () {
        var content;
        try {
            content = fs.read(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst');
            fs.remove(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst');
        } catch (ignore) {}

        test.assertMatch(content, /; Test Case File\n; generated by salmonJS v.+ \(.+\) at /);
        test.assertMatch(content, /\n; url = http:\/\/www.example.com\n; id = test\n\n\[GET\]\n\n\[POST\]\na=1\nb=2\n\n\[COOKIE\]\n\n\[HTTP_HEADERS\]\n\n\[CONFIRM\]\n\n\[PROMPT\]\n/, 'creates a file if url, name and data is not empty');
    });

    test.done();
});

casper.test.begin('getCases', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    testObj.parseCaseFile = function () { return {}; };

    test.assertEquals(testObj.getCases(''), [], 'doesn\'t return anything if there are no matches');
    test.assertEquals(testObj.getCases('non-existent'), [], 'doesn\'t return anything if there are no matches');

    fs.makeDirectory(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com');
    fs.write(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst', '[POST]\na=1\nb=2\n');
    testObj = new Test(fsWrapper, glob, rootdir, utils);
    testObj.parseCaseFile = function () { return {POST:{a: 1, b: 2}}; };

    test.assertEquals(testObj.getCases('http://www.example.com'), [{POST:{a: 1, b: 2}}], 'returns something if there are matches');
    fs.remove(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com/test.tst');

    test.done();
});

casper.test.begin('parseCaseFile', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    test.assertEquals(testObj.parseCaseFile('non-existent'), {}, 'doesn\'t parse a non existent file');

    test.done();
});

casper.test.begin('parseCaseFile #2', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    test.assertEquals(testObj.parseCaseFile('empty-file'), {}, 'parses an empty file');

    test.done();
});

casper.test.begin('parseCaseFile #3', function (test) {
    var Test      = require(srcdir + '/test'),
        fsWrapper = new (require(srcdir + '/fs'))(fs),
        utils     = {},
        testObj   = new Test(fsWrapper, glob, srcdir + '/..', utils);

    utils.parseINIString = function() { return {a: '1', b: '2'}; };
    testObj = new Test(fsWrapper, glob, srcdir + '/..', utils);
    fs.write(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'not-empty-file.tst', 'a=1\nb=2\n');
    test.assertEquals(testObj.parseCaseFile(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'not-empty-file.tst'), {a: '1', b: '2'}, 'parses a not empty file');
    fs.remove(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'not-empty-file.tst');

    fs.removeTree(srcdir + '/..' + testObj.TEST_CASE_DIRECTORY + 'http---www-example-com');

    test.done();
});
